Package: sigora
Type: Package
Title: Signature Overrepresentation Analysis
Version: 3.2.0
Date: 2026-03-21
Authors@R: c(
        person("Amir", "Foroushani",
        email = c("sigora.dev@gmail.com"),
        role = c("aut"),
        comment = c(ORCID = "0000-0003-2748-3009")),
        person("Fiona", "Brinkman",
        email = c("sigora.dev@gmail.com"),
        role = c("aut")),
        person("David", "Lynn",
        email = c("sigora.dev@gmail.com"),
        role = c("aut")),
        person("Witold", "Wolski",
        email = c("witold.wolski@fgcz.uzh.ch"),
        role = c("cre"),
        comment = c(ORCID = "0000-0002-6468-120X"))
        )
Depends: R (>= 3.0.0)
URL: https://github.com/wolski/sigora
BugReports: https://github.com/wolski/sigora/issues
Imports: stats, slam
Suggests: knitr, rmarkdown
Description: 
     Pathway Analysis is statistically linking observations on 
     the molecular level to biological processes or pathways on 
     the systems(i.e., organism, organ, tissue, cell) level.  
     Traditionally, pathway analysis methods regard pathways 
     as collections of single genes and treat all genes in a pathway
     as equally informative. However, this can lead to identifying
     spurious pathways as statistically significant since components
     are often shared amongst pathways. SIGORA seeks to avoid this
     pitfall by focusing on genes or gene pairs that are (as a combination)
     specific to a single pathway.
     In relying on such pathway gene-pair signatures (Pathway-GPS),
     SIGORA inherently uses the status of other genes in the
     experimental context to identify the most relevant pathways.
     The current version allows for pathway analysis of human
     and mouse datasets. In addition, it contains pre-computed
     Pathway-GPS data for pathways in the KEGG and  Reactome
     pathway repositories and mechanisms for extracting GPS
     for user-supplied repositories.
Encoding: UTF-8
License: GPL-3
NeedsCompilation: no
biocViews: GeneSetEnrichment, GO, Software, Pathways, KEGG
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Packaged: 2026-03-21 09:48:36 UTC; wolski
Author: Amir Foroushani [aut] (ORCID: <https://orcid.org/0000-0003-2748-3009>),
  Fiona Brinkman [aut],
  David Lynn [aut],
  Witold Wolski [cre] (ORCID: <https://orcid.org/0000-0002-6468-120X>)
Maintainer: Witold Wolski <witold.wolski@fgcz.uzh.ch>
Repository: CRAN
Date/Publication: 2026-03-21 10:30:02 UTC
Built: R 4.6.0; ; 2026-04-25 22:20:30 UTC; unix
